/*
 * Stellarium
 * Copyright (C) 2007 Fabien Chereau
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef STEXTURETYPES_HPP_
#define STEXTURETYPES_HPP_

#include <boost/shared_ptr.hpp>

class STexture;

//! In stellarium we now use shared pointer to simplify memory managment
typedef boost::shared_ptr<STexture> STextureSP;

namespace STextureTypes
{

//! Supported dynamic range modes
enum DynamicRangeMode
{
	LINEAR,
	MINMAX_USER,
	MINMAX_QUANTILE,
	MINMAX_GREYLEVEL,
	MINMAX_GREYLEVEL_AUTO
};
}
#endif /*STEXTURETYPES_HPP_*/
